@@ -22,7 +22,7 @@
 #include "config.h"
 
 #include "eds-buddy.h"
-
+#include "gdb-buddy.h"
 #include "bugzilla.h"
 #include "bug-buddy.h"
 #include "distribution.h"
@@ -38,8 +38,12 @@
 
 #include <errno.h>
 
+#include <glib.h>
+#include <glib/gstdio.h>
+#include <glib/gi18n.h>
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include <glade/glade.h>
 #include <glade/glade-build.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -71,6 +75,9 @@
 #define PROXY_USER	"/system/http_proxy/authentication_user"
 #define PROXY_PASSWORD	"/system/http_proxy/authentication_password"
 #define ACCESSIBILITY_KEY "/desktop/gnome/interface/accessibility"
+#define GTK_THEME_KEY	"/desktop/gnome/interface/gtk_theme"
+#define ICON_THEME_KEY  "/desktop/gnome/interface/icon_theme"
+#define DESKTOP_IS_HOME_DIR "/apps/nautilus/preferences/desktop_is_home_dir"
 
 static GOptionData gopt_data;
 static int bug_count = 0;
@@ -244,6 +251,8 @@ static gboolean
 delete_review (GtkWidget *widget, GdkEvent  *event, gpointer user_data)  
 {
 	gtk_widget_hide (widget);
+
+	return TRUE; /* don't destroy */
 }
 
 static void
@@ -299,7 +308,7 @@ get_gnome_version_info (void)
 	if (!doc)
 		return NULL;
 
-	platform = minor = micro = distributor = NULL;
+	platform = minor = micro = distributor = date = NULL;
 	
 	for (node = xmlDocGetRootElement (doc)->children; node; node = node->next) {
 		if (!strcmp ((char *)node->name, "platform"))
@@ -344,7 +353,7 @@ update_progress_bar (gpointer data)
 	return TRUE;
 }
 
-void
+static void
 save_email (const char *email)
 {
 	GConfClient *conf_client;
@@ -354,7 +363,7 @@ save_email (const char *email)
 	g_object_unref (conf_client);
 }
 
-void
+static void
 link_callback (GtkLinkButton *button, gpointer user_data)
 {
 	const gchar *link = gtk_link_button_get_uri (button);
@@ -373,20 +382,15 @@ link_callback (GtkLinkButton *button, gpointer user_data)
 static void
 save_to_file (const gchar *filename, const gchar *text)
 {
-	FILE          *bugfile;
+	GError *error = NULL;
 
-	if ((bugfile = fopen (filename, "w")) == NULL) {
-		g_warning ("Unable to save document %s\n", filename);
-		return;
+	if (!g_file_set_contents (filename, text, -1, &error)) {
+		g_warning ("Unable to save document %s: %s\n", filename, error->message);
+		g_error_free (error);
 	}
-
-	fwrite (text, g_utf8_strlen (text, -1), 1, bugfile);
-
-	fclose (bugfile);
 }
 
 
-
 static void
 network_error (SoupMessage *msg, GladeXML *xml)
 {
@@ -410,7 +414,7 @@ network_error (SoupMessage *msg, GladeXML *xml)
 	if (res == GTK_RESPONSE_YES) {
 		gchar *dirname;
 		gchar *filename;
-		gchar *message_string;
+		xmlChar *message_string;
 	       
 		dirname = g_strdup_printf ("%s/.gnome2/bug-buddy/pending_reports", g_get_home_dir ());
 		if (!g_file_test (dirname, G_FILE_TEST_IS_DIR)) {
@@ -421,9 +425,9 @@ network_error (SoupMessage *msg, GladeXML *xml)
 					
 		message_string = soup_xmlrpc_message_to_string (SOUP_XMLRPC_MESSAGE (msg));
 
-		save_to_file (filename, message_string);
+		save_to_file (filename, (const gchar*) message_string);
 
-		g_free (message_string);
+		xmlFree (message_string);
 		g_free (dirname);
 		g_free (filename);
 	}
@@ -431,7 +435,8 @@ network_error (SoupMessage *msg, GladeXML *xml)
 	bug_buddy_quit (xml);
 	return;
 }
-void
+
+static void
 remove_pending_reports (void)
 {
 		GDir *dir;
@@ -455,7 +460,7 @@ remove_pending_reports (void)
 		g_free (dirname);
 }
 
-void
+static void
 all_sent (GladeXML *xml)
 {
 	GtkWidget *close_button;
@@ -469,7 +474,7 @@ all_sent (GladeXML *xml)
 	gtk_widget_show (close_button);
 }
 
-void
+static void
 previous_sent (SoupMessage *msg, GladeXML *xml)
 {
 	if (--bug_count == 0) {
@@ -478,8 +483,7 @@ previous_sent (SoupMessage *msg, GladeXML *xml)
 }
 
 
-
-void
+static void
 bug_sent (SoupMessage *msg, GladeXML *xml)
 {
 	GtkWidget *button;
@@ -506,7 +510,7 @@ bug_sent (SoupMessage *msg, GladeXML *xml)
 		remove_pending_reports ();
 	}
 
-	/* parse the XML-RPC response from bugzilla */
+	/* parse the XML-RPC response from Bugzilla */
 	bugid = bugzilla_parse_response (msg, &err);
 
 	if (bugid > 0) {
@@ -516,7 +520,7 @@ bug_sent (SoupMessage *msg, GladeXML *xml)
 	 	* can add a GtkLinkButton to the bug report */
 		main_vbox = glade_xml_get_widget (xml, "main-vbox");
 
-		text = g_strdup_printf ("http://bugzilla.gnome.org/show_bug.cgi?id=%d", bugid);
+		text = g_strdup_printf ("http://bugzilla.gnome.org/show_bug.cgi?id=%ld", bugid);
 
 		/* create a clickable link to the bug report */
 		urlbutton = gtk_link_button_new (text);
@@ -672,8 +676,7 @@ static char*
 create_report_title (BugzillaApplication *app, int type, const char *description)
 {
 	char *title;
-	int limit;
-	long size;
+	long size = 0;
 	char *tmp = NULL;
 
 	if (description) {
@@ -716,7 +719,6 @@ send_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version, GladeXML
 	const char *email;
 	SoupSession *session;
         SoupXmlrpcMessage *message;
-	SoupXmlrpcResponse *response;
 	GError *err = NULL;
 
 	gtk_widget_hide (glade_xml_get_widget (xml, "pending-reports-check"));
@@ -1011,6 +1013,8 @@ create_debuginfo_link (void)
 
 	/* create a clickable link to the bug report */
 	urlbutton = gtk_link_button_new_with_label ("http://live.gnome.org/GettingTraces/DistroSpecificInstructions", 
+    	/* Translators: This is the hyperlink which takes to http://live.gnome.org/GettingTraces/DistroSpecificInstructions
+         * page. Please also mention that the page is in English */
 						    _("Getting useful crash reports"));
 	g_signal_connect (G_OBJECT (urlbutton), "clicked", G_CALLBACK (link_callback), NULL);
 
@@ -1149,9 +1153,12 @@ on_save_clicked (GtkWidget *button, gpointer user_data)
 {
 	GladeXML *xml = (GladeXML *)user_data;
 	GtkWidget *dialog;
-	gchar *desktop;
+	char *desktop;
 	char *filename;
-	gboolean saved = FALSE;
+	gboolean desktop_is_home_dir, saved;
+	GConfClient *gconf_client;
+	
+	saved = FALSE;
 
 	dialog = gtk_file_chooser_dialog_new ("Save File",
 	                                      GTK_WINDOW (glade_xml_get_widget (xml, "main-window")),
@@ -1162,7 +1169,15 @@ on_save_clicked (GtkWidget *button, gpointer user_data)
 
 	gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
 
-	desktop = g_strconcat (g_getenv ("HOME"), "/Desktop", NULL); 
+	gconf_client = gconf_client_get_default ();
+	desktop_is_home_dir = gconf_client_get_bool (gconf_client, DESKTOP_IS_HOME_DIR, NULL);
+	g_object_unref (gconf_client);
+
+	if (desktop_is_home_dir)
+		desktop = g_strdup (g_get_home_dir());
+	else
+		desktop = g_build_path ("/", g_get_home_dir(), "Desktop", NULL);
+
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), desktop);
 
 	filename = g_strconcat (gopt_data.app_file, _("-bugreport.txt"), NULL);
@@ -1494,10 +1509,17 @@ fill_system_info (GladeXML *xml)
 		g_string_append_printf (system_info, "Selinux: No\n");
 	}
 
+	/* A11y and gtk */
 	gconf_client = gconf_client_get_default ();
 	a11y = gconf_client_get_bool (gconf_client, ACCESSIBILITY_KEY, NULL);
-	g_object_unref (gconf_client);
 	g_string_append_printf (system_info, "Accessibility: %s\n", a11y?"Enabled":"Disabled");
+	str = gconf_client_get_string (gconf_client, GTK_THEME_KEY, NULL);
+	g_string_append_printf (system_info, "GTK+ Theme: %s\n", str);
+	g_free (str);
+	str = gconf_client_get_string (gconf_client, ICON_THEME_KEY, NULL);
+	g_string_append_printf (system_info, "Icon Theme: %s\n", str);
+	g_free (str);
+	g_object_unref (gconf_client);
 
 	g_string_append (system_info, "\n");
 	
@@ -1543,7 +1565,7 @@ fill_stderr_info (GladeXML *xml)
 			if (stat (file, &buf) == 0) {
 				age = time (NULL) - buf.st_mtime;
 				if (age > 5) {
-					mtime_age = g_strdup_printf (" (%d sec old)", age);
+					mtime_age = g_strdup_printf (" (%d sec old)", (int) age);
 				}
 			}
 				
@@ -1613,15 +1635,12 @@ load_icon (const char *icon)
 int
 main (int argc, char *argv[])
 {
-	GtkIconInfo *icon_info;
 	GladeXML *xml;
 	char *s;
-	char *bt;
-	GtkTextView *text_view;
 	BugzillaApplication *app;
 	GnomeVersionInfo *gnome_version;
 	guint progress;
-	GtkWidget *main_window, *statusbar;
+	GtkWidget *main_window;
 	GOptionContext *context;
 	GnomeProgram *program;
 	GError *err = NULL;
@@ -1634,7 +1653,7 @@ main (int argc, char *argv[])
 	textdomain (PACKAGE);
 
 	context = g_option_context_new (_("\n\nBug Buddy is a utility that helps report debugging\n"
-	                                  "information to the GNOME bugzilla when a program crashes."));
+	                                  "information to the GNOME Bugzilla when a program crashes."));
 
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
@@ -1642,14 +1661,15 @@ main (int argc, char *argv[])
 	                              LIBGNOMEUI_MODULE,
 	                              argc, argv,
 	                              GNOME_PARAM_GOPTION_CONTEXT, context,
-	                              GNOME_PARAM_APP_DATADIR, REAL_DATADIR,
+	                              GNOME_PARAM_APP_DATADIR, BUDDY_DATADIR,
+ 				      GNOME_CLIENT_PARAM_SM_CONNECT, FALSE,
 	                              NULL);
 
 	g_set_application_name (_("Bug Buddy"));
 	gtk_window_set_default_icon_name ("bug-buddy");
 
 	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-				       "bug-buddy/bug-buddy.glade", TRUE, NULL);
+				       "bug-buddy.glade", TRUE, NULL);
 	if (s)
 		xml = glade_xml_new (s, NULL, GETTEXT_PACKAGE);
 	else
@@ -1657,9 +1677,8 @@ main (int argc, char *argv[])
 
 	if (!xml) {
 		buddy_error (NULL, 
-			     _("Bug Buddy could not load its user interface file (%s).\n"
-			       "Please make sure Bug Buddy was installed correctly."), 
-			     s);
+			     _("Bug Buddy could not load its user interface file.\n"
+			       "Please make sure Bug Buddy was installed correctly."));
 		g_object_unref (program);
 		return 0;
 	}
@@ -1742,7 +1761,7 @@ main (int argc, char *argv[])
 
 		if (gopt_data.pid > 0) {
 			/* again, if this is an unknown application, we connect a different callback that
-	 		* will allow the user to save the trace rather than sending it to the GNOME bugzilla */
+	 		* will allow the user to save the trace rather than sending it to the GNOME Bugzilla */
 			if (app == NULL) {
 				source_id = gdb_get_trace (gopt_data.app_file, gopt_data.pid, xml, 
 		                           		   gdb_finished_unknown_app, &err);
