@@ -66,7 +66,7 @@
 #define BUGZILLA_COMPONENT              "X-GNOME-Bugzilla-Component"
 #define BUGZILLA_EMAIL                  "X-GNOME-Bugzilla-Email"
 #define BUGZILLA_VERSION                "X-GNOME-Bugzilla-Version"
-#define BUGZILLA_OTHER_BINARIES         "X-Gnome-Bugzilla-OtherBinaries"
+#define BUGZILLA_OTHER_BINARIES         "X-GNOME-Bugzilla-OtherBinaries"
 #define BUGZILLA_EXTRA_INFO_SCRIPT      "X-GNOME-Bugzilla-ExtraInfoScript"
 
 #define BA_BUGZILLA_BUGZILLA            "bugzilla:bugzilla"
@@ -112,6 +112,7 @@ add_bugzilla_application (GHashTable *hash,
 			char *s;
 			s = strrchr (programv[0], G_DIR_SEPARATOR);
 			s = s ? s+1 : programv[0];
+			app->ref_count += 1;
 			g_hash_table_insert (hash, g_strdup (s), app);
 		} else {
 			g_free (app);
@@ -124,6 +125,7 @@ add_bugzilla_application (GHashTable *hash,
 	if (other_programs) {
 		programv = g_strsplit (other_programs, ";", -1);
 		for (i=0; programv[i]; i++) {
+			app->ref_count += 1;
 			g_hash_table_insert (hash, g_strdup (programv[i]), app);
 		}
 		g_strfreev (programv);
@@ -133,6 +135,10 @@ add_bugzilla_application (GHashTable *hash,
 static void
 application_free (BugzillaApplication *app)
 {
+	app->ref_count -= 1;
+	if (app->ref_count > 0)
+		return;
+
 	g_free (app->name);
 	g_free (app->cname);
 	g_free (app->comment);
